@@ -14,7 +14,7 @@ def AnswerView(request):
         else:
             search_in = ""
 
-        draft = request.GET["draft"]
+        draft = request.GET.get("draft", False)
 
         answers = get_answers(question, search_in, draft)
 
